[Spice-devel] [PATCH 18/19] display: rename detach_streams_behind

Frediano Ziglio fziglio at redhat.com
Wed Nov 25 07:27:42 PST 2015


From: Marc-André Lureau <marcandre.lureau at gmail.com>

---
 server/display-channel.c | 12 ++++++------
 server/display-channel.h |  1 -
 server/stream.c          |  2 +-
 server/stream.h          |  3 +++
 4 files changed, 10 insertions(+), 8 deletions(-)

diff --git a/server/display-channel.h b/server/display-channel.h
index b89f84e..0e0c1f1 100644
--- a/server/display-channel.h
+++ b/server/display-channel.h
@@ -432,7 +432,6 @@ static inline void region_add_clip_rects(QRegion *rgn, SpiceClipRects *data)
     }
 }
 
-void detach_streams_behind(DisplayChannel *display, QRegion *region, Drawable *drawable);
 void drawable_draw(DisplayChannel *display, Drawable *item);
 void drawables_init(DisplayChannel *display);
 
diff --git a/server/stream.c b/server/stream.c
index 50881e5..33a9893 100644
--- a/server/stream.c
+++ b/server/stream.c
@@ -842,7 +842,7 @@ static void detach_stream_gracefully(DisplayChannel *display, Stream *stream,
  *           involves sending an upgrade image to the client, this drawable won't be rendered
  *           (see dcc_detach_stream_gracefully).
  */
-void detach_streams_behind(DisplayChannel *display, QRegion *region, Drawable *drawable)
+void stream_detach_behind(DisplayChannel *display, QRegion *region, Drawable *drawable)
 {
     Ring *ring = &display->streams;
     RingItem *item = ring_get_head(ring);
diff --git a/server/stream.h b/server/stream.h
index b11b10f..d7d9a37 100644
--- a/server/stream.h
+++ b/server/stream.h
@@ -159,6 +159,9 @@ void                  stream_timeout                                (DisplayChan
 void                  stream_detach_and_stop                        (DisplayChannel *display);
 void                  stream_trace_add_drawable                     (DisplayChannel *display,
                                                                      Drawable *item);
+void                  stream_detach_behind                          (DisplayChannel *display,
+                                                                     QRegion *region,
+                                                                     Drawable *drawable);
 
 void                  stream_agent_unref                            (DisplayChannel *display,
                                                                      StreamAgent *agent);
diff --git a/server/display-channel.c b/server/display-channel.c
index f2c3fc6..811799a 100644
--- a/server/display-channel.c
+++ b/server/display-channel.c
@@ -711,7 +711,7 @@ static int current_add_with_shadow(DisplayChannel *display, Ring *ring, Drawable
 
     // only primary surface streams are supported
     if (is_primary_surface(display, item->surface_id)) {
-        detach_streams_behind(display, &shadow->base.rgn, NULL);
+        stream_detach_behind(display, &shadow->base.rgn, NULL);
     }
 
     ring_add(ring, &shadow->base.siblings_link);
@@ -724,7 +724,7 @@ static int current_add_with_shadow(DisplayChannel *display, Ring *ring, Drawable
         streams_update_visible_region(display, item);
     } else {
         if (is_primary_surface(display, item->surface_id)) {
-            detach_streams_behind(display, &item->tree_item.base.rgn, item);
+            stream_detach_behind(display, &item->tree_item.base.rgn, item);
         }
     }
     stat_add(&display->add_stat, start_time);
@@ -834,14 +834,14 @@ static int current_add(DisplayChannel *display, Ring *ring, Drawable *drawable)
         current_add_drawable(display, drawable, ring);
     } else {
         /*
          * red_detach_streams_behind can affect the current tree since
          * it may trigger calls to display_channel_draw. Thus, the
          * drawable should be added to the tree before calling
-         * red_detach_streams_behind
+         * stream_detach_behind
          */
         current_add_drawable(display, drawable, ring);
         if (is_primary_surface(display, drawable->surface_id)) {
-            detach_streams_behind(display, &drawable->tree_item.base.rgn, drawable);
+            stream_detach_behind(display, &drawable->tree_item.base.rgn, drawable);
         }
     }
     region_destroy(&exclude_rgn);
@@ -1024,7 +1024,7 @@ static int handle_surface_deps(DisplayChannel *display, Drawable *drawable)
                 QRegion depend_region;
                 region_init(&depend_region);
                 region_add(&depend_region, &drawable->red_drawable->surfaces_rects[x]);
-                detach_streams_behind(display, &depend_region, NULL);
+                stream_detach_behind(display, &depend_region, NULL);
             }
         }
     }
@@ -834,14 +834,14 @@ static int current_add(DisplayChannel *display, Ring *ring, Drawable *drawable)
     } else {
         /*
-         * red_detach_streams_behind can affect the current tree since
+         * stream_detach_behind can affect the current tree since
          * it may trigger calls to display_channel_draw. Thus, the
          * drawable should be added to the tree before calling
-- 
2.4.3



More information about the Spice-devel mailing list